#include "Monocle.h"
#include "Graphics/SpriteAnimation.h"
#include "LevelEditor/LevelEditor.h"

using namespace Monocle;

namespace Dark
{
  class Player : public Entity
  {
  public:
    Player();
    void Update();

    Vector2 velocity;
    float noisiness;

    SpriteAnimation *sprite;
    Entity *dark;
    AudioDeck *footsteps;

    int const FRICTION;
    float const MAXSPEED;
    int const ACCELERATION;    
  };

  class Creature : public Entity
  {
  public:
    Creature();
    void Update();

    Vector2 velocity;
    Vector2 direction;
    float aiTime;
    float noiseTime;
    std::string state;

    SpriteAnimation *sprite;
    AudioDeck *skitter1;
    AudioAsset *alert;
    AudioAsset *stalk;

    int const FRICTION;
    float const MAXSPEED;
    int const ACCELERATION;
    float const STALKSPEED;
    float const HUNTSPEED;
  };

  class Ping : public Entity
  {
  public:
    Ping();
    void Update();
    static Ping *NewPing(Vector2 pos, float d1, float d2, float t2);

    float d1, d2, t, t2;

    Sprite *sprite;
  };

  class DarkScene : public Scene
  {
  public:
    DarkScene();
    void Begin();
    void Update();

    LevelEditor *levelEditor;
    
    Player *player;
  };

  class Text: public Entity
  {
  public:
    Text(const std::string& text, FontAsset* font=NULL);
    
    void Render();
    
    void SetFont(FontAsset* font) { this->font = font; }
    void SetText(const std::string& text) { this->text = text; }
    
  protected:
    FontAsset* font;
    std::string text;
  };
}

